*==============================================================================
* Function:			ExecScript
* Purpose:			Executes the specified code (VFP 6 SP3 or later is required)
* Author:			Doug Hennig
* Copyright:		(c) 2000 Stonefield Systems Group Inc.
* Last revision:	10/07/2000
* Parameters:		tcCode - the code to execute
* Returns:			the return value of the code or .NULL. if it couldn't run
* Environment in:	none
* Environment out:	whatever effect the code had
*==============================================================================

lparameters tcCode
local luReturn, ;
	lcVersion, ;
	lcFile, ;
	lcName, ;
	luReturn

* Ensure the parameters were passed correctly.

assert vartype(tcCode) = 'C' and not empty(tcCode) ;
	message 'ExecScript: invalid tcCode parameter'

* Initialize the return value to .NULL. in case something goes wrong, then test
* which version of VFP we're running.

luReturn = .NULL.
#if type('version(4)') <> 'U'
	lcVersion = version(4)
	lcVersion = substr(lcVersion, at('.', lcVersion, 2) + 1)

* If we have VFP 6 SP3 or later, write the code to a temporary file, compile
* and execute it, then erase the file and the FXP we created.

	if lcVersion >= '8492'
		lcFile = 'A' + sys(3) + '.PRG'
		strtofile(tcCode, lcFile)
		compile (lcFile)
		lcName   = juststem(lcFile) + '()'
		luReturn = &lcName
		erase (lcFile)
		erase forceext(lcFile, 'FXP')
	endif lcVersion >= '8492'
#else
	error 'ExecScript requires VFP 6 SP 3 or later'
#endif
return luReturn
